<?php

/**
 * Class responsible for handling our Ajax requests from the checkout page.
 *
 * Author:          Uriahs Victor
 * Created on:      27/11/2022 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Controllers
 */
namespace Lpac_DPS\Controllers\Checkout_Page\Ajax;

if ( !defined( 'ABSPATH' ) ) {
    exit;
}
use  Lpac_DPS\Controllers\Checkout_Page\Base_Checkout_Page_Controller ;
/**
 * Class Handlers.
 *
 * @package Lpac_DPS\Controllers\Checkout_Page\Ajax
 */
class Handlers extends Base_Checkout_Page_Controller
{
    /**
     * Ajax controller method for lpac_dps_get_times.
     *
     * @return void
     * @since 1.0.0
     */
    public function get_times_ajax_handler() : void
    {
        $date_data = array_map( 'sanitize_text_field', wp_unslash( $_REQUEST['selectedDate'] ?? array() ) );
        if ( empty($date_data) ) {
            wp_send_json_error( 'Date data empty.', 500 );
        }
        $date = sanitize_text_field( $date_data['date'] );
        $day_of_the_week = $this->days_of_the_week[sanitize_text_field( $date_data['dayIndex'] )] ?? '';
        $order_type = sanitize_text_field( $date_data['orderType'] );
        $time_slots_nested_repeater = $this->base_model::get_setting( "{$order_type}__time_slots_nested_repeater" );
        $all_times = array_column( $time_slots_nested_repeater, 'time_slots', 'day_of_the_week' );
        $times_for_day = $all_times[$day_of_the_week] ?? array();
        
        if ( empty($times_for_day) ) {
            wp_send_json_success( 'set_manually' );
            // Allow customer to set their delivery or pickup time manually.
        }
        
        $time_slots = '';
        foreach ( $times_for_day as $index => $data ) {
            $from = $data['time_range']['from'];
            $to = $data['time_range']['to'];
            $from_to = $this->get_from_to_time_slot_text( $from, $to );
            
            if ( !empty($to) ) {
                $time_slots .= "<option value='{$from_to}'>" . $from_to . '</option>';
            } else {
                $time_slots .= "<option value='{$from}'>" . $from . '</option>';
            }
        
        }
        wp_send_json_success( $time_slots );
    }

}