<?php
/**
 * Base controller class.
 *
 * Author:          Uriahs Victor
 * Created on:      17/11/2022 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Controllers
 */

namespace Lpac_DPS\Controllers\Checkout_Page;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Lpac_DPS\Controllers\Base_Controller;
use Lpac_DPS\Models\Base_Model;

/**
 * Class Base_Checkout_Page_Controller.
 *
 * @package Lpac_DPS\Controllers\Checkout_Page
 * @since 1.0.0
 */
class Base_Checkout_Page_Controller extends Base_Controller {

	/**
	 * Instance of Base_Model class.
	 *
	 * @var Base_Model
	 */
	protected $base_model;

	/**
	 * Houses controller methods needed specifically for checkout page logic.
	 *
	 * @package Lpac_DPS\Controllers\Checkout_Page
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->base_model = new Base_Model();
	}

	/**
	 * Create a range text given the from and to. Example: 12:00 AM - 12:00 PM.
	 *
	 * @param string $from The from time.
	 * @param string $to The to time.
	 * @return string
	 * @since 1.0.0
	 */
	protected function get_from_to_time_slot_text( string $from, string $to ) : string {
		return $from . ' - ' . $to;
	}

	/**
	 * Replace dashes in a date with underscores. Example: 2022_11_27.
	 *
	 * @param string $date The date.
	 * @return string
	 * @since 1.0.0
	 */
	protected function get_date_underscored( string $date ): string {
		return str_replace( '-', '_', $date );
	}

	/**
	 * Replace spaces in a time slot with underscores. Example: 12:00_AM_-_12:00_PM.
	 *
	 * @param string $time_slot The timeslot.
	 * @return string
	 * @since 1.0.0
	 */
	protected function get_time_slot_underscored( string $time_slot ): string {
		return str_replace( ' ', '_', $time_slot );
	}

}
