<?php
/**
 * File responsible for methods to do with manipulating Emails.
 *
 * Author:          Uriahs Victor
 * Created on:      04/04/2023 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.6
 * @package Controllers
 */

namespace Lpac_DPS\Controllers;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Lpac_DPS\Helpers\Functions;
use Lpac_DPS\Models\Plugin_Settings\General_Settings;

/**
 * Class responsible for methods that manipulate Emails.
 *
 * @package Lpac_DPS\Controllers
 * @since 1.0.6
 */
class Emails {

	/**
	 * Show our date and time inside order emails.
	 *
	 * @param mixed $order
	 * @param mixed $sent_to_admin
	 * @param mixed $plain_text
	 * @param mixed $email
	 * @return void
	 * @since 1.0.6
	 */
	public function addDateTimeToEmails( $order, $sent_to_admin, $plain_text, $email ) {
		$allowed_emails = General_Settings::getDateTimeIncludedEmails();

		if ( ! is_object( $email ) ) {
			return;
		}

		// If the current email ID is not in our list of allowed emails then bail.
		if ( ! in_array( $email->id, $allowed_emails ) ) {
			return;
		}

		$order_type = $order->get_meta( 'lpac_dps_order_type' );
		if ( 'delivery' === $order_type ) {
			$order_date = $order->get_meta( 'lpac_dps_delivery_date' );
			$order_date = Functions::getFormattedDate( $order_date );

			$order_time = $order->get_meta( 'lpac_dps_delivery_time' );

		} else {
			$order_date = $order->get_meta( 'lpac_dps_pickup_date' );
			$order_date = Functions::getFormattedDate( $order_date );

			$order_time = $order->get_meta( 'lpac_dps_pickup_time' );
		}

		?>
		<div style='text-align: center !important'>
			<p><strong><?php esc_html_e( 'Order Type', 'delivery-and-pickup-scheduling-for-woocommerce' ); ?>:</strong> <span><?php echo esc_html( ucfirst( $order_type ) ); ?></span></p>
			<?php if ( ! empty( $order_date ) ) : ?>
			<p><strong><?php esc_html_e( 'Date', 'delivery-and-pickup-scheduling-for-woocommerce' ); ?>:</strong> <span><?php echo esc_html( $order_date ); ?></span> </p>
			<?php endif ?>
			<?php if ( ! empty( $order_time ) ) : ?>
			<p><strong><?php esc_html_e( 'Time', 'delivery-and-pickup-scheduling-for-woocommerce' ); ?>:</strong> <span><?php echo esc_html( $order_time ); ?></span> </p>
			<?php endif ?>
		</div>
		<?php
	}

}
