<?php
/**
 * File responsible for creating helper functions.
 *
 * Author:          Uriahs Victor
 * Created on:      23/03/2023 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Helpers
 */

namespace Lpac_DPS\Helpers;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Lpac_DPS\Models\Plugin_Settings\General_Settings;

/**
 * Class responsible for creating commonly used helper functions.
 *
 * @package Lpac_DPS\Helpers
 * @since 1.0.0
 */
class Functions {

	/**
	 * Get all available user roles on a website.
	 *
	 * @return array
	 * @since 1.0.0
	 */
	public static function get_available_user_roles(): array {
		global $wp_roles;
		$roles = array_keys( $wp_roles->roles );
		return array_combine( $roles, $roles );
	}

	/**
	 * Get the roles assigned to the current user.
	 *
	 * @return array
	 * @since 1.0.0
	 */
	public static function get_current_user_roles(): array {
		$user  = wp_get_current_user();
		$roles = (array) $user->roles;
		return $roles;
	}

	/**
	 * Format a date.
	 *
	 * @param mixed $date The date to format.
	 * @return string
	 * @since 1.0.6
	 */
	public static function getFormattedDate( $date ): string {
		return date_format( date_create( $date ), General_Settings::get_preferred_date_format() );
	}
}
