<?php
/**
 * Base model class.
 *
 * Author:          Uriahs Victor
 * Created on:      25/11/2022 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Models
 */

namespace Lpac_DPS\Models;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Base_Model.
 *
 * @package Lpac_DPS\Models
 * @since 1.0.0
 */
class Base_Model {

	/**
	 * Days of the week.
	 *
	 * @var array
	 * @since 1.0.0
	 */
	protected $days_of_the_week = array(
		'sunday', // Counting of days of the week starts on Sunday with an index of 0.
		'monday',
		'tuesday',
		'wednesday',
		'thursday',
		'friday',
		'saturday',
	);

	/**
	 * Get a specific settings option from settings array.
	 *
	 * @param string $option The option setting to retrieve from the settings array.
	 * @param string $default The value to return if no value exists.
	 * @return mixed
	 * @since 1.0.0
	 */
	public static function get_setting( string $option = '', $default = '' ) {
		$options = get_option( 'lpac_dps' );
		return ( isset( $options[ $option ] ) ) ? $options[ $option ] : $default;
	}

}
