<?php
/**
 * Class responsible for grabbing Order Type settings.
 *
 * Author:          Uriahs Victor
 * Created on:      29/12/2022 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Models
 */

namespace Lpac_DPS\Models\Plugin_Settings;

use Lpac_DPS\Models\Base_Model;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Order_Type
 *
 * Class responsible for getting Order Type settings.
 *
 * @package Lpac_DPS\Models\Plugin_Settings
 * @since 1.0.0
 */
class Order_Type extends Base_Model {

	/**
	 * Get the default Order Type that should be selected at checkout.
	 *
	 * @return string
	 * @since 1.0.0
	 */
	public function get_default_order_type(): string {
		return self::get_setting( 'order_type__default' );
	}

	/**
	 * Check if delivery is enabled on the website.
	 *
	 * @return bool
	 * @since 1.0.0
	 */
	public function is_delivery_enabled(): bool {
		return (bool) self::get_setting( 'order_type__enable_delivery' );
	}

	/**
	 * Check if pickup is enabled on the website.
	 *
	 * @return bool
	 * @since 1.0.0
	 */
	public function is_pickup_enabled(): bool {
		return (bool) self::get_setting( 'order_type__enable_pickup' );
	}

}
