<?php
/**
 * Class responsible for upsell notices.
 *
 * Author:         Uriahs Victor
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Notices
 */

namespace Lpac_DPS\Notices;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Lpac_DPS\Notices\Notice;
use Lpac_DPS\Traits\Plugin_Info;

/**
 * Class Upsells_Notices.
 */
class Upsells_Notices extends Notice {

	use Plugin_Info;

	/**
	 * Class constructor
	 *
	 * @return void
	 */
	public function __construct() {
		$this->create_pro_notice();
	}

	/**
	 * Create initial pro released notice.
	 *
	 * @return void
	 */
	public function create_pro_notice() {

		$installed_plugins = get_plugins();

		$is_pro = array_key_exists( 'delivery-and-pickup-scheduling-pro/delivery-and-pickup-scheduling.php', $installed_plugins );

		if ( $is_pro ) {
			return;
		}

		$days_since_installed = $this->get_days_since_installed();

		// Show notice after 1 month and a week.
		if ( $days_since_installed < 35 ) {
			return;
		}

		$content = array(
			'title' => __( 'Upgrade to Delivery & Pickup Scheduling PRO!', 'delivery-and-pickup-scheduling-for-woocommerce' ),
			'body'  => __( 'Elevate your store 🚀 Checkout the PRO version of Delivery & Pickup Scheduling for WooCommerce.', 'delivery-and-pickup-scheduling-for-woocommerce' ),
			'link'  => 'https://dpswp.com',
		);

		$this->create_notice_markup( 'initial_pro_launch_notice', $content );
	}
}
