<?php
/**
 * Houses Order related View methods.
 *
 * Author:          Uriahs Victor
 * Created on:      17/11/2022 (d/m/y)
 *
 * @link    https://uriahsvictor.com
 * @since   1.0.0
 * @package Views
 */

namespace Lpac_DPS\Views\Admin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Lpac_DPS\Helpers\Functions;
use Lpac_DPS\Models\Base_Model;

/**
 * Class Order.
 */
class Order {

	/**
	 * The format in which dates should be displayed.
	 *
	 * @var string
	 * @since 1.0.0
	 */
	private $date_format;

	/**
	 * Holds the order details.
	 *
	 * @var array
	 * @since 1.0.0
	 */
	private $order_details = array();

	/**
	 * Class constructor.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->date_format = Base_Model::get_setting( 'general__date_format', 'F j, Y' );
	}

	/**
	 * Output our delivery data to the metabox.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	public function output_order_details_metabox_content() :void {

		$order_type = $this->order_details['lpac_dps_order_type'][0] ?? '';
		$date       = $this->order_details[ "lpac_dps_{$order_type}_date" ][0] ?? '';

		$date_formatted = '';
		if ( ! empty( $date ) ) {
			$date_formatted = Functions::getFormattedDate( $date );
		}

		$time = $this->order_details[ "lpac_dps_{$order_type}_time" ][0] ?? '';

		?>
		<div style='text-align: center; font-weight: 500'>
		<?php if ( ! empty( $date_formatted ) ) { ?>
			<p><span class='dashicons dashicons-calendar-alt'></span> <?php echo esc_html( $date_formatted ); ?></p>
		<?php } ?>
		<?php if ( ! empty( $time ) ) { ?>
			<p style='border-bottom: 1px dashed #e3e3e3; padding-bottom: 10px;'><span class='dashicons dashicons-clock'></span> <?php echo esc_html( $time ); ?></p>
		<?php } ?>
		<p id='lpac-dps-countdown-timer' style='font-size: 20px; margin: 10px 0;'></p>
		</div>
		<?php
	}

	/**
	 * Create our metabox to hold the delivery/pickup details.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	public function create_metabox(): void {
		$order = get_post_meta( get_the_ID() );

		$this->order_details = $order;
		$order_type          = $order['lpac_dps_order_type'][0] ?? '';

		if ( 'delivery' !== $order_type && 'pickup' !== $order_type ) {
			return; // Something is wrong, bail (check order type value saved for order).
		}

		$title = ( 'delivery' === $order_type ) ? __( 'Delivery details', 'delivery-and-pickup-scheduling-for-woocommerce' ) : __( 'Pickup details', 'delivery-and-pickup-scheduling-for-woocommerce' );
		add_meta_box( 'lpac_dps_metabox', $title, array( $this, 'output_order_details_metabox_content' ), 'shop_order', 'side', 'high' );
	}



}
